@@ -6,7 +6,13 @@ import sys
 import uuid
 import warnings
 from os.path import expanduser
-from typing import Any, Dict, Optional, Sequence, Tuple, Union
+from typing import Any, Dict, Optional, Sequence, Tuple, Union, TYPE_CHECKING
+from collections import Counter
+
+import hubble
+
+if TYPE_CHECKING:  # pragma: no cover
+    from docarray import DocumentArray
 
 __resources_path__ = os.path.join(
     os.path.dirname(
@@ -146,14 +152,6 @@ def download_mermaid_url(mermaid_url, output) -> None:
         raise RuntimeError('Invalid or too-complicated graph')
 
 
-def get_request_header() -> Dict:
-    """Return the header of request.
-
-    :return: request header
-    """
-    return {k: str(v) for k, v in get_full_version().items()}
-
-
 def get_full_version() -> Dict:
     """
     Get the version of libraries used in Jina and environment variables.
@@ -168,7 +166,7 @@ def get_full_version() -> Dict:
     return {
         'docarray': __version__,
         'protobuf': google.protobuf.__version__,
-        'proto-backend': api_implementation._default_implementation_type,
+        'proto-backend': api_implementation.Type(),
         'python': platform.python_version(),
         'platform': platform.system(),
         'platform-release': platform.release(),
@@ -455,3 +453,52 @@ def _safe_cast_int(value: Union[str, int, float]) -> int:
     if isinstance(value, float) and not value.is_integer():
         raise ValueError(f"Can't safely cast {value} to an int")
     return int(value)
+
+
+def _get_array_info(da: 'DocumentArray'):
+    all_attrs = da._get_attributes('non_empty_fields')
+    # remove underscore attribute
+    all_attrs = [tuple(vv for vv in v if not vv.startswith('_')) for v in all_attrs]
+    attr_counter = Counter(all_attrs)
+
+    all_attrs_names = set(v for k in all_attrs for v in k)
+    _nested_in = []
+    if 'chunks' in all_attrs_names:
+        _nested_in.append('chunks')
+
+    if 'matches' in all_attrs_names:
+        _nested_in.append('matches')
+
+    is_homo = len(attr_counter) == 1
+
+    _nested_items = []
+    if not is_homo:
+        for n_attributes, n_docs in attr_counter.most_common():
+            if n_docs == 1:
+                _doc_text = f'{n_docs} Document has'
+            else:
+                _doc_text = f'{n_docs} Documents have'
+            if len(n_attributes) == 1:
+                _text = f'{_doc_text} one attribute'
+            elif len(n_attributes) == 0:
+                _text = f'{_doc_text} no attribute'
+            else:
+                _text = f'{_doc_text} attributes'
+            _nested_items.append(
+                dict(name=_text, value=str(n_attributes), description='')
+            )
+
+    return is_homo, _nested_in, _nested_items, attr_counter, all_attrs_names
+
+
+def login(interactive: Optional[bool] = None, force: bool = False, **kwargs):
+    """Login to Jina AI Cloud account.
+    :param interactive: If set to true, login will support notebook environments, otherwise the enviroment will be inferred.
+    :param force: If set to true, overwrite token and re-login.
+    """
+    hubble.login(interactive=interactive, force=force)
+
+
+def logout():
+    """Log out of Hubble account."""
+    hubble.logout()
